@@ -9,6 +9,24 @@
 //  Module:         Configuration utility
 // ****************************************************************************
 
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Guy Voncken
+//
+// This file is part of libguytools.
+//
+// libguytools is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
+// (at your option) any later version.
+//
+// libguytools is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with libguytools. If not, see <http://www.gnu.org/licenses/>.
+
 /* ------------------------------ */
 /*           Includes             */
 /* ------------------------------ */
@@ -19,6 +37,7 @@
 #include <limits.h>
 #include <string.h>
 #include <time.h>
+#include <locale.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -677,8 +696,8 @@ static APIRET ToolCfgQueryFileInfo (t_pchar pFileName, t_pint pYear, t_pint pMon
    }
 
    LastModified = localtime (&(FileInfo.st_mtime));
-   if (pYear  ) *pYear   = LastModified->tm_year;
-   if (pMonth ) *pMonth  = LastModified->tm_mon;
+   if (pYear  ) *pYear   = LastModified->tm_year + 1900;
+   if (pMonth ) *pMonth  = LastModified->tm_mon  +    1;
    if (pDay   ) *pDay    = LastModified->tm_mday;
    if (pHour  ) *pHour   = LastModified->tm_hour;
    if (pMinute) *pMinute = LastModified->tm_min;
@@ -835,7 +854,7 @@ static APIRET ToolCfgGetLineLen (t_pToolCfgContext pCfgContext)
                           pEol++;
 
                           CopyLen = pCfgContext->pBuffer + pCfgContext->BufferLen - pEol;
-                          memcpy (pLastBackslash, pEol, CopyLen);
+                          memmove (pLastBackslash, pEol, CopyLen);
                           pEol = pLastBackslash;
                           pLastBackslash = NULL;
                           pCfgContext->ActLineNr++;
@@ -919,9 +938,10 @@ static APIRET ToolCfgDropContext (t_pToolCfgContext pCfgContext)
    return NO_ERROR;
 }
 
-/* CfgGetNextLine is the core function of the configuration scanner. From the calling    */
-/* function's point of view, it simply reads the next line (or returns ppLine = NULL if  */
-/* no more data can be found). Internally it manages the INCLUDE and SECTION statements. */
+/* CfgGetNextLine is the core function of the configuration scanner. From the calling   */
+/* function's point of view, it simply reads the next line (or returns ppLine = NULL if */
+/* no more data can be found). Internally it manages the INCLUDE and SECTION statements */
+/* as well as trailing backslashes (for joining lines).                                 */
 static APIRET ToolCfgGetNextLine (t_pchar *ppLine, t_pint pLineLen)
 {
    t_pToolCfgContext pContext;
@@ -1306,12 +1326,13 @@ static APIRET ToolCfgConvertpParamToInteger (t_pchar pParam, t_int ParamLen, t_p
 
 static APIRET ToolCfgConvertpParamToDouble (t_pchar pParam, t_int ParamLen, t_pdouble pValue)
 {
-   t_int       rc;
-   long double LongDoubleVal;
-//   t_pchar    pOldLocale;
-   t_int       i;
-   t_int       DecimalPoint;
-   t_int       Exponent;
+   t_int         rc;
+   long double   LongDoubleVal;
+   t_pchar     pOldLocale;
+   t_pchar     pSavedLocale;
+   t_int         i;
+   t_int         DecimalPoint;
+   t_int         Exponent;
 
    // Check all the chars in the param to detect entry errors
    // Convert ',' to '.'
@@ -1375,12 +1396,14 @@ static APIRET ToolCfgConvertpParamToDouble (t_pchar pParam, t_int ParamLen, t_pd
       }
    }
 
-   // switch the 'locale' to accept '.' as decimal point,          // So far, so good, but: the locale functions unser OS/2 are
-   // scan the double value and switch back.                       // extremely slow! they require several seconds while scanning
-   //   pOldLocale = setlocale (LC_NUMERIC, NULL);                 // the configuration file (measured by IXTRA)! That's the reason
-   //   (void) setlocale (LC_NUMERIC, LC_C_USA);                   // why we trust in the US default.
+   // switch the 'locale' to accept '.' as decimal point,
+   // scan the double value and switch back.
+   pOldLocale = setlocale (LC_NUMERIC, NULL);
+   pSavedLocale = strdup (pOldLocale);
+   (void) setlocale (LC_NUMERIC, "C");
    rc = sscanf (pParam, "%LG", &LongDoubleVal);
-   //   (void) setlocale (LC_NUMERIC, pOldLocale);
+   (void) setlocale (LC_NUMERIC, pSavedLocale);
+   free (pSavedLocale);
 
    if (rc!=1)
    {
